@@ -10,6 +10,7 @@ all the user actions to CEM fo logging/mentor input/game input."
 
 #include <fcntl.h> //we check some files
 #include <string.h> //we use strcmp
+#include <pthread.h> // we use threads when debugging
 
 #include "gui.h"
 #include "chum.h"
@@ -18,6 +19,8 @@ all the user actions to CEM fo logging/mentor input/game input."
 #include "../cem/cem.h"
 #include "../meam/meam.h"
 
+#include "../gems/gems.h"
+
 static int chum_count_themes();
 static void chum_play_recorded_and_backing_track();
 
@@ -38,11 +41,57 @@ return state_of_chum;
 //THIS IS THE MAIN LOOP OF JAMMO!!!
 void chum_start_jammo_main_loop() {
     cem_add_to_log("starting main loop",LOG_DEBUG);
-    meam_start_gstreamer_loop(); 
+    //meam_start_gstreamer_loop();
+
+    //This is not good for jammoterminal but it works.
+    //gtk_main();
+    gui_start_main_loop();
+    //clutter_init();
+    //clutter_main();
     cem_add_to_log("main loop is over",LOG_DEBUG);
 }
 
 
+void *debug_test_wait_and_start_seq(){
+  printf("wait_and_start_seq\n");
+  g_usleep( 1 * G_USEC_PER_SEC );
+  chum_play_sequencer();
+  pthread_exit(NULL);
+}
+
+void debug_test_minimal_recording(int different_way) {
+    int song_number=4;
+    cem_add_to_log(g_strdup_printf("debug_test_minimal_recording(%d)",different_way),LOG_DEBUG);
+    current_song=song_number;
+
+    const gchar *song_folder=chum_get_song_folder(song_number);
+    gchar *filename = g_strdup_printf("%s/comping.ogg", song_folder);
+    
+    if (different_way==0)
+      {
+      cem_add_to_log(g_strdup_printf("making new_empty_track and put sample to it"),LOG_DEBUG);
+      chum_create_new_empty_track(); //for comping track
+      chum_add_new_sample_to_track_nth_slot(0,filename,0);
+      }
+    else
+      {
+      cem_add_to_log(g_strdup_printf("making own track type _without_ gnonlin."),LOG_DEBUG);
+      create_new_backing_track(filename);
+      }
+
+
+    create_new_singing_track();
+
+    pthread_t loop_thread;
+    pthread_create(&loop_thread, NULL, debug_test_wait_and_start_seq, NULL);
+
+    GMainLoop *loop;
+    loop = g_main_loop_new (NULL, FALSE);
+    g_main_loop_run (loop);
+    //This is useless:
+    pthread_exit(NULL);
+}
+
 
 void chum_start_chum(int argc, char** argv){
     int i;
@@ -55,7 +104,6 @@ void chum_start_chum(int argc, char** argv){
     meam_init();
     number_of_themes=chum_count_themes();
 
-    gui_init();
     if (argc==2 && strcmp(argv[1],"--help")==0) {
         printf("\nJamMo help:\n\n");
         printf("flags:\n");
@@ -64,7 +112,19 @@ void chum_start_chum(int argc, char** argv){
         exit(0);
         }
 
-    else if (argc==2 && strcmp(argv[1],"sing")==0) { 
+    else if (argc==2 && strcmp(argv[1],"debug0")==0) { 
+        debug_test_minimal_recording(0);
+        exit(0);
+        }
+    else if (argc==2 && strcmp(argv[1],"debug1")==0) { 
+        debug_test_minimal_recording(1);
+        exit(0);
+        }
+
+
+
+    gui_init();
+    if (argc==2 && strcmp(argv[1],"sing")==0) { 
         state_of_chum=SCREEN_SONG_SELECTION;
         }
 
@@ -72,9 +132,14 @@ void chum_start_chum(int argc, char** argv){
         state_of_chum=SCREEN_MIDI_EDITOR;
         }
 
+    else if (argc==2 && strcmp(argv[1],"theme")==0) { 
+        state_of_chum=SCREEN_THEME_SELECTION;
+        }
+
+
     else if (argc==3 && strcmp(argv[1],"theme")==0) { 
-        chum_change_to_theme(atoi(argv[2]));
-        //It triggers two time gui_go_screen(state_of_chum);
+        chum_change_theme(atoi(argv[2]));
+        state_of_chum=SCREEN_COMPOSING;
         }
 
 
@@ -154,13 +219,18 @@ int chum_get_current_theme(){
     return current_theme;
 }
 
-
-void chum_change_to_theme(int theme_number){
-    cem_add_to_log(g_strdup_printf("chum_change_to_theme(%d)",theme_number),LOG_DEBUG);
+void chum_create_new_empty_track() {
+  cem_add_to_log(g_strdup_printf("chum_create_new_empty_track()"),LOG_DEBUG);
+  meam_create_new_empty_track();
+}
+void chum_change_theme(int theme_number){
+    cem_add_to_log(g_strdup_printf("chum_change_theme(%d)",theme_number),LOG_DEBUG);
     current_theme=theme_number;
-    //FIXME. make new tracks and check tempo and meter.
-    meam_seq_remove_samples_from_track(0);
-    meam_seq_remove_samples_from_track(1);
+
+    g_list_foreach(get_mainPipeline()->tracks, (GFunc)remove_track, NULL);
+    chum_create_new_empty_track(); //for samples
+    chum_create_new_empty_track(); //for backing track
+
 
     //Add backing track if there are.
     gchar* filepath1 = g_strdup_printf("%s/%s/backing_track.wav", THEMES_DIR, chum_get_theme_folder(chum_get_current_theme()));
@@ -168,6 +238,12 @@ void chum_change_to_theme(int theme_number){
     if (fd != -1)
 	meam_seq_add_new_sample_to_track(1,filepath1,0); //trac-number,file,starting position
 
+    state_of_chum=SCREEN_COMPOSING;
+    //gui_go_screen(state_of_chum);
+}
+
+void chum_change_to_theme(int theme_number){
+chum_change_theme(theme_number);
     state_of_chum=SCREEN_COMPOSING;
     gui_go_screen(state_of_chum);
 }
@@ -199,13 +275,13 @@ static void chum_play_recorded_and_backing_track(){
     g_list_foreach(get_mainPipeline()->tracks, (GFunc)remove_track, NULL);
 
 
-    create_new_empty_track(); //for comping track
+    chum_create_new_empty_track(); //for comping track
     const gchar *song_folder=chum_get_song_folder(chum_get_current_song());
     gchar *filename = g_strdup_printf("%s/comping.ogg", song_folder);
     chum_add_new_sample_to_track_nth_slot(0,filename,0);
 
 
-    create_new_empty_track(); //for recorded singing
+    chum_create_new_empty_track(); //for recorded singing
     chum_add_new_sample_to_track_nth_slot(1,REC_TARGET,0);
 }
 
@@ -220,8 +296,7 @@ void chum_change_to_song(int song_number){
     const gchar *song_folder=chum_get_song_folder(song_number);
 
     g_list_foreach(get_mainPipeline()->tracks, (GFunc)remove_track, NULL);
-    create_new_empty_track(); //for comping track
-    create_new_empty_track(); //some reason, there must be two new track. FIXME
+    chum_create_new_empty_track(); //for comping track
     gchar *filename = g_strdup_printf("%s/comping.ogg", song_folder);
     chum_add_new_sample_to_track_nth_slot(0,filename,0);
 
@@ -242,14 +317,13 @@ void chum_stop_one_sample(){
 
 void chum_stop_sequencer(){
     cem_add_to_log("chum_stop_sequencer()",LOG_DEBUG);
-    meam_stop_one_sample();
     meam_seq_stop();
 }
 
 void chum_play_sequencer(){
-    cem_add_to_log("chum_play_sequencer()",LOG_DEBUG);
     chum_stop_sequencer();
-    gui_visualize_playing();
+    cem_add_to_log("chum_play_sequencer()",LOG_DEBUG);
+    gui_visualize_playing(state_of_chum);
     meam_seq_play();
 }
 
@@ -287,6 +361,7 @@ meam_remove_sample_from_slot(track_number,slot);
 const gchar* theme_folders[MAX_NUMBER_OF_THEMES];
 
 const gchar* chum_get_theme_folder(int index){
+//cem_add_to_log(g_strdup_printf("chum_get_theme_folder(%d). we will return %s",index,theme_folders[index]),LOG_DEBUG);
     return theme_folders[index];
 }
 
