@@ -37,7 +37,8 @@ void chum_go_back();
 void chum_go_next();
 void chum_go_screen(int screen_number);
 void chum_change_to_game(int game_number);
-void chum_change_to_theme(int theme_number);
+void chum_change_theme(int theme_number);
+void chum_create_new_empty_track();
 
 int chum_get_current_theme();
 const char* chum_get_theme_folder(int index);
