@@ -11,27 +11,22 @@ Graphical user interface must implement all these functions.
 #define HEIGHT_OF_WINDOW 480
 //These are different state of Game.
 enum {
-  SCREEN_WELCOME,
-  SCREEN_GAME_SELECTION,
+  SCREEN_WELCOME = 0,
+  SCREEN_GAME_SELECTION, //This is main-menu
   SCREEN_THEME_SELECTION,
   SCREEN_COMPOSING,
   SCREEN_SONG_SELECTION,
   SCREEN_SONG_RECORDING,
   SCREEN_PLAY_RECORDED,
   SCREEN_MIDI_EDITOR,
+  NUMBER_OF_SCREENS, //Keep this entry last.
 };
 
-//Compile same time with both GUIs.
-//do not include either.
-
-//Selecting which gui is used.
-//#include "../gui_clutter/clutter_jammo.h"
-//#include "../gui_terminal/terminal_jammo.h"
-
 void gui_go_screen(int number);
 void gui_init();
 void gui_visualize_playing();
 void gui_visualize_contour(float freq);
 
+void gui_start_main_loop();
 
 #endif /*  _GUI_H_  */
