@@ -28,12 +28,19 @@ Read more about clutter: http://clutter-project.org/
 #include "jammo-texture.h"
 #include "json_helper.h" //there are generate_json_for_theme
 
+#include "preloader.h"
+#include "welcome_demo.h"
+#include "main_menu.h"
 //Games
 #include "composing_game.h"
 #include "singing_game.h"
-#include "instrument_testing.h" //For testing virtual instruments (and slider)
+//#include "instrument_testing.h" //For testing virtual instruments (and slider)
+#include "midi_editor.h"
 
-#include "midi_editor.h" //This will go under advanced composing game
+void gui_start_main_loop(){
+    //clutter_init();
+    clutter_main();
+}
 
 ClutterColor trans_color = { 0, 0, 0, 0x00 };
 ClutterColor dark_color =  { 0, 0, 0, 0xdd };
@@ -45,154 +52,45 @@ ClutterColor *get_white_color(){        return &white_color; }
 ClutterColor *get_dark_color(){         return &dark_color;  }
 ClutterColor *get_blue_color(){         return &blue_color;  }
 
-
 ClutterActor* stage;
-
 ClutterActor* main_getStage(){
   return stage;
 }
 
-//////For welcome screen, animating door opening
-#define angle_of_opened_door 110.0
-gdouble door_rotating=0.0;
-static gboolean rotate_actor (gpointer data){
-  door_rotating-=0.8;
-  clutter_actor_set_rotation(CLUTTER_ACTOR(data),CLUTTER_Y_AXIS,door_rotating,0,0,0);
-
-  if (door_rotating>-angle_of_opened_door)
-    return TRUE;
-
-  //just be sure, that there aren't any sounds when going next step.
-  chum_stop_one_sample();
-  chum_go_next();
-  return FALSE;
+void gui_visualize_playing(int state) {
+  if (state==SCREEN_COMPOSING)
+      composing_game_visualize_playing();
+  else if (state==SCREEN_PLAY_RECORDED)
+      printf("#####state is Screen_play_recorded and sequencer started\n");
+  else
+      printf("#####gui_visualize_playing: state is %d \n",state);
 }
 
-static void welcome_end (JammoTexture *actor, ClutterEvent *event, gpointer data){
-  //if pressed already
-  if (door_rotating<0.0)
-    {
-    door_rotating=-angle_of_opened_door;
-    return;
-    }
-
-  g_timeout_add (50,rotate_actor,actor);
-  chum_play_one_sample(g_strdup_printf("%s/door_opening.wav",DATA_DIR));
-}
-
-
-static void show_welcome(){
-  ClutterActor* stage =main_getStage();
-
-  ClutterActor *s1 = config_get_configured_actor(NULL,"welcome");
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), s1);
-  clutter_actor_show (s1);
-  clutter_actor_set_reactive(s1, TRUE);
-  clutter_actor_set_name(s1, "welcome");
-
-  s1 = config_get_configured_actor(NULL,"door");
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), s1);
-
-  clutter_actor_show (s1);
-  clutter_actor_set_reactive(s1, TRUE);
-  clutter_actor_set_name(s1, "door");
-  g_signal_connect (s1, "button-release-event", G_CALLBACK (welcome_end),NULL);
-}
-
-
-
-static void compose_clicked(){
-chum_go_screen(SCREEN_THEME_SELECTION);
-}
-
-static void singing_clicked(){
-chum_go_screen(SCREEN_SONG_SELECTION);
-}
-
-
-void show_game_selection() {
-  ClutterActor* stage =main_getStage();
-
-  ClutterActor *s1 = config_get_configured_actor(NULL,"house");
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), s1);
-  clutter_actor_show (s1);
-  clutter_actor_set_name(s1, "house");
-
-  s1 = config_get_configured_actor(NULL,"select_singing");
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), s1);
-  clutter_actor_show (s1);
-  clutter_actor_set_reactive(s1, TRUE);
-  clutter_actor_set_name(s1, "select_singing");
-  g_signal_connect (s1, "button-release-event", G_CALLBACK (singing_clicked),NULL);
-
-  s1 = config_get_configured_actor(NULL,"select_composing");
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), s1);
-  clutter_actor_show (s1);
-  clutter_actor_set_reactive(s1, TRUE);
-  clutter_actor_set_name(s1, "select_composing");
-  g_signal_connect (s1, "button-release-event", G_CALLBACK (compose_clicked),NULL);
-
-  s1 = config_get_configured_actor(NULL,"select_ud");
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), s1);
-  clutter_actor_show (s1);
-  clutter_actor_set_reactive(s1, TRUE);
-  clutter_actor_set_name(s1, "select_ud");
-  g_signal_connect (s1, "button-release-event", G_CALLBACK (start_test_instrument),GINT_TO_POINTER(2));
-
-  s1 = config_get_configured_actor(NULL,"select_drum");
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), s1);
-  clutter_actor_show (s1);
-  clutter_actor_set_reactive(s1, TRUE);
-  clutter_actor_set_name(s1, "select_drum");
-  g_signal_connect (s1, "button-release-event", G_CALLBACK (start_test_instrument),GINT_TO_POINTER(1));
-
-  s1 = config_get_configured_actor(NULL,"select_flute");
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), s1);
-  clutter_actor_show (s1);
-  clutter_actor_set_reactive(s1, TRUE);
-  clutter_actor_set_name(s1, "select_flute");
-  g_signal_connect (s1, "button-release-event", G_CALLBACK (start_test_instrument),GINT_TO_POINTER(0));
-
-  s1 = config_get_configured_actor(NULL,"select_loading");
-  clutter_container_add_actor (CLUTTER_CONTAINER (stage), s1);
-  clutter_actor_set_size(s1,60,60);
-  clutter_actor_set_position(s1,10,400);
-  clutter_actor_show (s1);
-  clutter_actor_set_reactive(s1, TRUE);
-  clutter_actor_set_name(s1, "house");
-  g_signal_connect (s1, "button-release-event", G_CALLBACK (start_slider),NULL);
-}
-
-
-
-/////////////////////////////////////////////////
 void gui_go_screen(int screen_number) {
   if (screen_number==SCREEN_WELCOME){
-    show_welcome();
+    show_welcome();              //welcome_demo.c
   } else if (screen_number==SCREEN_GAME_SELECTION){
-    show_game_selection();
+    show_game_selection();        //main_menu.c
   } else if (screen_number==SCREEN_THEME_SELECTION){
-    show_theme_selection();
+    show_theme_selection();       //composing_game.c
   } else if (screen_number==SCREEN_COMPOSING){
-    start_theme();
+    start_theme();               //composing_game.c
   } else if (screen_number==SCREEN_SONG_SELECTION){
-    start_mobikid_selection();
+    start_mobikid_selection();   //singing_game.c
   } else if (screen_number==SCREEN_SONG_RECORDING){
-    start_mobikid_recording();
+    start_mobikid_recording();   //singing_game.c
   } else if (screen_number==SCREEN_PLAY_RECORDED){
-    start_mobikid_play_recorded();
+    start_mobikid_play_recorded();      //singing_game.c
   } else if (screen_number==SCREEN_MIDI_EDITOR){
-    start_midi_editor();
+    start_midi_editor();                //midi_editor.c
   }
 
 }
 
 
-
-/*We aren't using gtk-loop/clutter_main, but pipelines loop*/
 void window_closed(void) {
   printf("window is closed\n");
-  g_main_loop_quit(get_mainPipeline()->loop); 
+  clutter_main_quit();
   }
 
 GdkPixbuf *create_pixbuf(const gchar * filename)
@@ -223,6 +121,7 @@ static void event_handler (ClutterActor    *actor,
     }
 }
 
+
 void gui_init() {
       int i;
       gint number_of_themes =chum_get_number_of_themes();
@@ -232,6 +131,7 @@ void gui_init() {
       }
 
       clutter_init(NULL,NULL);
+      //clutter_threads_init();
 
       //stage is global
       stage = clutter_stage_get_default();
@@ -243,11 +143,16 @@ void gui_init() {
 
       #ifdef N900
       clutter_stage_set_fullscreen(CLUTTER_STAGE(stage),TRUE);
+
       #endif
       clutter_actor_show_all(stage);
+      preloader_start(); //this will start some threads and return immediatly.
 
+      #ifdef START_JOYSTICK_THREAD
+      /* temporaly disabled */
       pthread_t loop_thread;
       pthread_create(&loop_thread, NULL, start_reading_joystick, NULL);
+      #endif
 }
 
 #ifdef clutter_gtk_way
