@@ -185,6 +185,7 @@ void start_mobikid_play_recorded(){
 }
 
 void start_mobikid_recording(){
+  printf("start_mobikid_recording starts\n");
   ClutterActor* stage =main_getStage();
 
   clutter_actor_hide(group_of_songs);
@@ -212,7 +213,7 @@ void start_mobikid_recording(){
   clutter_actor_show (next);
   clutter_actor_raise_top (next);
 
-
+  printf("will start sequencer\n");
   chum_play_sequencer();
 }
 
@@ -220,7 +221,7 @@ void start_mobikid_recording(){
 /*
 We can come to this function
 a) from game selection (main menu)
-b) after one song is singed
+b) after one song is sung
 
 */
 void start_mobikid_selection(){
