@@ -26,6 +26,15 @@ void gui_visualize_contour(float freq) {
 printf("frequence is %f\n",freq);
 }
 
+GMainLoop *loop;
+void gui_start_main_loop(){
+  loop = g_main_loop_new (NULL, FALSE);
+  g_main_loop_run (loop);
+}
+
+static void quit(){
+  g_main_loop_quit (loop);
+}
 
 /*
 For reading one char, without echoing it
@@ -74,7 +83,7 @@ static void show_theme_selection() {
     int number_of_themes =chum_get_number_of_themes();
       if (number_of_themes==0)  {
 	  printf("ERROR, JamMo doesn't find any theme.\n");
-	  exit(1);
+	  quit();
       }
 	
     printf("Theme selection menu: press theme number 1-%d. Or 'x' to quit.\n",number_of_themes);
@@ -85,14 +94,15 @@ static void show_theme_selection() {
     }
 
     int ch=mygetch();
-    if (ch=='x') exit(0);
+    if (ch=='x') quit();
     int selected=ch-48;
     if (selected<1 || selected>number_of_themes) {
 	printf("not valid selection!\n");
 	show_theme_selection();
 	return;
     }
-    chum_change_to_theme(ch-48);
+    chum_change_theme(ch-48);
+    gui_go_screen(SCREEN_COMPOSING);
 }
 
 
@@ -120,7 +130,7 @@ static void load_theme(const gchar *theme_folder) {
   ifp = fopen(objects_filename, "r");
   if (ifp == NULL) {
       fprintf(stderr, "Can't open input file '%s'\n",objects_filename);
-      exit(1);
+      quit();
   }
 
   //This is the loop which read whole file until end is reached
@@ -208,8 +218,8 @@ static void *start_theme() {
       switch (ch)
 	{
 	case 'x':
-	  printf("\n\nQUITTED\n\n");
-	  exit(1);
+	  printf("\n\nx pressed - QUITTED\n\n");
+          quit();
 	break;
 
 	case 'h':
@@ -320,7 +330,8 @@ static void *start_theme() {
 	}
 	ch=mygetch();
     }
-
+  //This is useless:
+  pthread_exit(NULL);
 }
 
 void gui_go_screen(int screen_number) {
