@@ -123,6 +123,61 @@ void create_new_empty_track_with_tempo_and_meter(guint tempo,guint meter) {
 }
 
 
+//Testing without gnonlin.
+static void
+on_pad_added (GstElement *element,
+              GstPad     *pad,
+              gpointer    data)
+{
+  GstPad *sinkpad;
+  GstElement *decoder = (GstElement *) data;
+  /* We can now link this pad with the vorbis-decoder sink pad */
+  g_print ("Dynamic pad created, linking demuxer/decoder\n");
+  sinkpad = gst_element_get_static_pad (decoder, "sink");
+  gst_pad_link (pad, sinkpad);
+  gst_object_unref (sinkpad);
+}
+/**
+ *  create_new_empty_track - Function for adding new empty track, after this function you can add samples 
+ *  to the track with add_audiosrc_to_track function.
+ */
+Track *create_new_backing_track(gchar *filename)
+{
+  Track *trc = (Track*) malloc(sizeof(Track));
+  if(trc != NULL)
+  {
+    GstElement  *convert, *source1;
+
+    /*track 1 uses these */
+    GstElement *demuxer1, *decoder1;
+
+    /* Create gstreamer elements */
+    convert  = gst_element_factory_make ("audioconvert",  NULL);
+  
+
+    /*track 1*/
+    source1   = gst_element_factory_make ("filesrc",       NULL);
+    demuxer1  = gst_element_factory_make ("oggdemux",      NULL);        ///
+    decoder1  = gst_element_factory_make ("vorbisdec",     NULL);     ///
+
+    g_object_set (G_OBJECT (source1), "location", filename, NULL);
+  
+    /* add all elements into the pipeline */
+   gst_bin_add_many (GST_BIN (get_mainPipeline()->pipeline),
+                        source1, demuxer1, decoder1,
+                        convert,  NULL);
+ 
+  
+   gst_element_link (source1, demuxer1);
+   gst_element_link_many (decoder1, convert,  NULL);
+   g_signal_connect (demuxer1, "pad-added", G_CALLBACK (on_pad_added), decoder1);
+
+   gst_element_link(convert, get_mainPipeline()->adder);
+   get_mainPipeline()->tracks = g_list_append(get_mainPipeline()->tracks, trc);
+   }
+   return trc;
+}
+
 /**
 Create track for recording from microphone.
 Save wav to file.
@@ -152,7 +207,6 @@ void create_new_singing_track(void)
 	pitchdetect = gst_element_factory_make ("pitchdetect", "pitchdetect");
 
 
-
 	#ifdef N810
 	GstElement *parse = NULL;
            source = gst_element_factory_make("dsppcmsrc", NULL);
@@ -182,11 +236,19 @@ void create_new_singing_track(void)
 	gchar converterA_nbr[15];
 	GstElement *encoder;
 
-	source = gst_element_factory_make("autoaudiosrc", NULL);
+         /*
+         GstCaps *filter;
+         filter = gst_caps_new_simple("audio/x-raw-int",
+          "channels", G_TYPE_INT, 1,
+          "rate", G_TYPE_INT, 8000,
+          "depth", G_TYPE_INT, 16, NULL);
+          */
+        source = gst_element_factory_make("autoaudiosrc", NULL);
 	sprintf(converterA_nbr, "converterA_%d", track_number);
 	audioconvertA = gst_element_factory_make("audioconvert", converterA_nbr);
 	encoder = gst_element_factory_make("wavenc", NULL);
-	gst_bin_add_many(GST_BIN(trc->trackbin),source, pitchdetect,audioconvertA, encoder,sink,NULL);
+	//gst_bin_add_many(GST_BIN(trc->trackbin),source, pitchdetect,audioconvertA, filter, encoder,sink,NULL);
+        gst_bin_add_many(GST_BIN(trc->trackbin),source, pitchdetect,audioconvertA, encoder,sink,NULL);
 
 	if (!gst_element_link (source, pitchdetect))
 	  {
@@ -199,8 +261,9 @@ void create_new_singing_track(void)
 	  return;
 	  }
 	if (!gst_element_link (audioconvertA,encoder))
+        //if (!gst_element_link_filtered(audioconvertA, encoder, filter))
 	  {
-	  g_print("gst_element_link error (audioconvertA,encoder)!\n");
+	  g_print("gst_element_link_filtered error (audioconvertA,encoder)!\n");
 	  return;
 	  }
 
@@ -210,28 +273,16 @@ void create_new_singing_track(void)
 	  return;
 	  }
 
-/*
-	if (!gst_element_link_many(source, pitchdetect,audioconvertA, sink, encoder, NULL))
-            g_print("gst_element_link failed for source,pitchdetect, audioconvertA, encoder, sink,NULL \n");
-*/
 	#endif
 
 
   
 	//add this track to mainpipeline
 	gst_bin_add(GST_BIN(get_mainPipeline()->pipeline), trc->trackbin);
-	//gst_element_link(trc->trackbin, get_mainPipeline()->adder);
-	if(GST_PAD_LINK_SUCCESSFUL(GST_PAD_LINK_OK))
-		g_print("Linking successfully completed (Track -> Adder)\n");
-	else 
-		g_print("Linking failed! (Track -> Adder)\n");
-
 	get_mainPipeline()->tracks = g_list_append(get_mainPipeline()->tracks, trc);
-
-
 	trc->samples = NULL;
 	}
-//return trc;
+
 }
 
 #define INSTRUMENT_FOLDER g_strdup_printf("%s/virtual-instruments/",DATA_DIR)
